---
title: Install Jekyll on Windows
permalink: doc_installation.html
keywords: jekyll on windows, pc, ruby, ruby dev kit
sidebar: doc_sidebar
folder: doc
---

# Installation OpenFOAM

requires OpenFOAM of2012 sourced and installed

```
./Allwmake
```
# Installation Testsuite

install oftest to automatically test OpenFOAM with py.test

```
pip install oftest
```

{% include links.html %}
